/// <reference types="bn.js" />
import { networkConfigType } from '../config/default-network-config';
import { BN } from 'ethereumjs-util';
import { ProcessDescription } from 'pm2';
import tcache from './tcache';
export declare const cache: tcache;
export declare const networkAccount = "1000000000000000000000000000000000000000000000000000000000000001";
/**
 * Fetches a new random active node from the network.
 * Saves to file by overwriting the previous active node.
 * Also saves the active node to a global variable.
 *
 * @param config
 * @returns {Promise<void>}
 * @throws {Error} If unable to fetch list of nodes in the network
 */
export declare function getNewActiveNode(config: networkConfigType): Promise<void>;
export declare function fetchInitialParameters(config: networkConfigType): Promise<{
    nodeRewardAmount: BN;
    nodeRewardInterval: BN;
}>;
/**
 *
 * @param config node config to get url and port
 * @throws {AxiosError} Status 404. If unable to fetch node-info
 * @returns nodeInfo
 */
export declare function fetchNodeInfo(config: networkConfigType): Promise<any>;
export declare function getNetworkParams(config: networkConfigType, description: ProcessDescription): Promise<{} | null>;
export declare function fetchEOADetails(config: networkConfigType, eoaAddress: string): Promise<{
    data: unknown;
    operatorAccountInfo: {
        stake: {
            value: string;
        };
        nominee: string;
    };
    reward: {
        value: string;
    };
} | undefined>;
export declare function fetchUnstakeableDetails(config: networkConfigType, nominee: string, nominator: string): Promise<{
    unlocked: boolean;
    reason: string;
    remainingTime: number;
} | undefined>;
export declare function fetchValidatorVersions(config: networkConfigType): Promise<{
    minVersion: string;
    activeVersion: string;
} | undefined>;
export declare function getAccountInfoParams(config: networkConfigType, nodePubKey: string): Promise<{
    lockedStake: string;
    nominator: string;
    accumulatedRewards: BN;
    totalPenalty: string;
}>;
export declare function fetchStakeParameters(config: networkConfigType): Promise<{
    stakeRequired: string;
}>;
export declare function fetchCycleDuration(config: networkConfigType): Promise<number>;
export declare function fetchGenesisStatus(config: networkConfigType, pubKey: string): Promise<boolean>;
