"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNodeSettings = exports.getProgressData = exports.getExitInformation = exports.fetchNodeProgress = exports.fetchStartSummary = exports.fetchExitSummary = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const utils_1 = require("../utils");
function fetchExitSummary() {
    return fetchFromLog(`${utils_1.File.EXIT_SUMMARY}`);
}
exports.fetchExitSummary = fetchExitSummary;
function fetchStartSummary() {
    return fetchFromLog(`${utils_1.File.START_SUMMARY}`);
}
exports.fetchStartSummary = fetchStartSummary;
async function fetchNodeProgress() {
    return fetchFromLog(`${utils_1.File.NODE_PROGRESS}`);
}
exports.fetchNodeProgress = fetchNodeProgress;
async function getExitInformation() {
    const exitSummary = fetchExitSummary();
    const startSummary = fetchStartSummary();
    const interceptExitMessage = (message) => {
        if (message.includes('Fatal: submitJoin: our node')) {
            return 'Unable to access external or internal ports. Please provide proper port access to the external and internal ports of shardeum  (9001 / 10001 are the defaults)';
        }
        return message;
    };
    // don't show exit reason if the validator is running or was never started
    const showExitReason = (exitSummary === null || exitSummary === void 0 ? void 0 : exitSummary.exitTime) > (startSummary === null || startSummary === void 0 ? void 0 : startSummary.startTime) ||
        ((startSummary === null || startSummary === void 0 ? void 0 : startSummary.startTime) == null && (exitSummary === null || exitSummary === void 0 ? void 0 : exitSummary.exitTime) != null);
    const exitMessage = showExitReason
        ? interceptExitMessage(exitSummary === null || exitSummary === void 0 ? void 0 : exitSummary.message)
        : undefined;
    const exitStatus = showExitReason ? exitSummary === null || exitSummary === void 0 ? void 0 : exitSummary.status : undefined;
    return { exitMessage, exitStatus };
}
exports.getExitInformation = getExitInformation;
function getProgressData(nodeProgress) {
    var _a, _b;
    if (!nodeProgress) {
        return {
            state: 'standby',
            totalTimeValidating: '00:00:00',
            lastActive: '',
            lastRotationIndex: '',
            nodeInfo: '',
        };
    }
    const lastRotationIndexSafe = (_a = nodeProgress.lastRotationIndex) !== null && _a !== void 0 ? _a : {
        idx: 0,
        total: 0,
    };
    const lastActiveTimeSafe = (_b = nodeProgress.lastActiveTime) !== null && _b !== void 0 ? _b : 0;
    const startData = fetchFromLog(`${utils_1.File.START_SUMMARY}`);
    if (startData.startTime >
        // eslint-disable-next-line security/detect-non-literal-fs-filename
        fs_1.default.statSync(path_1.default.join(__dirname, `../../logs/${utils_1.File.NODE_PROGRESS}`))
            .mtimeMs) {
        nodeProgress.totalActiveTime = 0;
        nodeProgress.nodeInfo.status = 'standby';
    }
    const LastActiveDate = new Date(lastActiveTimeSafe);
    return {
        state: nodeProgress.nodeInfo.status,
        totalTimeValidating: convertMsToDHM(nodeProgress.totalActiveTime),
        lastActive: lastActiveTimeSafe
            ? `${LastActiveDate.toDateString()} ${LastActiveDate.toTimeString()}`
            : '',
        lastRotationIndex: `${lastRotationIndexSafe.idx}/${lastRotationIndexSafe.total}`,
        nodeInfo: nodeProgress.nodeInfo,
    };
}
exports.getProgressData = getProgressData;
function getNodeSettings() {
    // eslint-disable-next-line security/detect-non-literal-fs-filename
    if (!fs_1.default.existsSync(path_1.default.join(__dirname, `../../${utils_1.File.NODE_CONFIG}`))) {
        return null;
    }
    const settingsData = path_1.default.join(__dirname, `../../${utils_1.File.NODE_CONFIG}`);
    // eslint-disable-next-line security/detect-non-literal-fs-filename
    return JSON.parse(fs_1.default.readFileSync(settingsData).toString());
}
exports.getNodeSettings = getNodeSettings;
function validatorLogExists(logName) {
    // eslint-disable-next-line security/detect-non-literal-fs-filename
    return fs_1.default.existsSync(path_1.default.join(__dirname, `../../logs/${logName}`));
}
function fetchFromLog(logName) {
    if (!validatorLogExists(logName)) {
        return null;
    }
    const logData = path_1.default.join(__dirname, `../../logs/${logName}`);
    // eslint-disable-next-line security/detect-non-literal-fs-filename
    return JSON.parse(fs_1.default.readFileSync(logData).toString());
}
function convertMsToDHM(ms) {
    if (ms === 0)
        return '00:00:00';
    const seconds = Math.floor(ms / 1000);
    const minutes = Math.floor(seconds / 60);
    const hours = Math.floor(minutes / 60);
    const days = Math.floor(hours / 24);
    const remainingHours = hours % 24;
    const remainingMinutes = minutes % 60;
    const daysString = days > 0 ? `${days} Days ` : '';
    const hoursString = remainingHours > 0 ? `${remainingHours} Hours ` : '';
    const minutesString = remainingMinutes > 0 ? `${remainingMinutes} Minutes` : '';
    return `${daysString}${hoursString}${minutesString}`;
}
//# sourceMappingURL=fetch-node-data.js.map