"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCommitHashForValidator = exports.getCommitHashForGUI = exports.getCommitHashForCLI = exports.getBranchNameForValidator = exports.getBranchNameForGUI = exports.getBranchNameForCLI = exports.isValidatorInstalled = exports.isGuiInstalled = exports.getInstalledValidatorVersion = exports.getInstalledGuiVersion = exports.getLatestGuiVersion = exports.getLatestCliVersion = void 0;
const axios_1 = __importDefault(require("axios"));
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const child_process_1 = require("child_process");
const CLI_LOCAL_PATH = path_1.default.join(__dirname, '../../');
const GUI_LOCAL_PATH = path_1.default.join(__dirname, '../../../../gui');
const VALIDATOR_LOCAL_PATH = path_1.default.join(__dirname, '../../../../validator');
async function getLatestCliVersion() {
    const packageJsonURI = `https://raw.githubusercontent.com/shardeum/validator-cli/dev/package.json`;
    const json = await axios_1.default.get(packageJsonURI);
    return json.data.version;
}
exports.getLatestCliVersion = getLatestCliVersion;
async function getLatestGuiVersion() {
    const packageJsonURI = `https://raw.githubusercontent.com/shardeum/validator-gui/dev/package.json`;
    const json = await axios_1.default.get(packageJsonURI);
    return json.data.version;
}
exports.getLatestGuiVersion = getLatestGuiVersion;
function getInstalledGuiVersion() {
    if (!isGuiInstalled()) {
        return;
    }
    const guiPackageJsonPath = path_1.default.join(GUI_LOCAL_PATH, '/package.json');
    const packageJson = JSON.parse(fs_1.default.readFileSync(guiPackageJsonPath).toString());
    return packageJson.version;
}
exports.getInstalledGuiVersion = getInstalledGuiVersion;
function getInstalledValidatorVersion() {
    if (!isValidatorInstalled()) {
        return;
    }
    const validatorPackageJsonPath = path_1.default.join(VALIDATOR_LOCAL_PATH, '/package.json');
    const packageJson = JSON.parse(fs_1.default.readFileSync(validatorPackageJsonPath).toString());
    return packageJson.version;
}
exports.getInstalledValidatorVersion = getInstalledValidatorVersion;
function isGuiInstalled() {
    return fs_1.default.existsSync(GUI_LOCAL_PATH);
}
exports.isGuiInstalled = isGuiInstalled;
function isValidatorInstalled() {
    return fs_1.default.existsSync(VALIDATOR_LOCAL_PATH);
}
exports.isValidatorInstalled = isValidatorInstalled;
function getBranchNameForCLI() {
    return getBranchNameFor(CLI_LOCAL_PATH);
}
exports.getBranchNameForCLI = getBranchNameForCLI;
function getBranchNameForGUI() {
    return getBranchNameFor(GUI_LOCAL_PATH);
}
exports.getBranchNameForGUI = getBranchNameForGUI;
function getBranchNameForValidator() {
    return getBranchNameFor(VALIDATOR_LOCAL_PATH);
}
exports.getBranchNameForValidator = getBranchNameForValidator;
function getCommitHashForCLI() {
    return getCommitHash(CLI_LOCAL_PATH);
}
exports.getCommitHashForCLI = getCommitHashForCLI;
function getCommitHashForGUI() {
    return getCommitHash(GUI_LOCAL_PATH);
}
exports.getCommitHashForGUI = getCommitHashForGUI;
function getCommitHashForValidator() {
    return getCommitHash(VALIDATOR_LOCAL_PATH);
}
exports.getCommitHashForValidator = getCommitHashForValidator;
const getBranchNameFor = (dirPath) => new Promise(resolve => {
    // eslint-disable-next-line security/detect-child-process
    (0, child_process_1.exec)(`git -C ${path_1.default.join(dirPath)} branch --show-current`, (error, stdout) => resolve(!error ? stdout.trim() : 'unknown'));
});
const getCommitHash = (dirPath) => new Promise(resolve => {
    // eslint-disable-next-line security/detect-child-process
    (0, child_process_1.exec)(`git -C ${path_1.default.join(dirPath)} rev-parse HEAD`, (error, stdout) => resolve(!error ? stdout.trim() : 'unknown'));
});
//# sourceMappingURL=project-data.js.map