"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const _1 = require(".");
class tcache {
    constructor() {
        this.val = new Map();
        this.time = new Map();
        this.valPath = path_1.default.join(__dirname, `${_1.File.VAL}`);
        this.timePath = path_1.default.join(__dirname, `${_1.File.TIME}`);
        this.readMaps();
    }
    readMaps() {
        // Skip if files don't exist
        // eslint-disable-next-line security/detect-non-literal-fs-filename
        if (!fs_1.default.existsSync(this.valPath) || !fs_1.default.existsSync(this.timePath)) {
            return;
        }
        // eslint-disable-next-line security/detect-non-literal-fs-filename
        const valStr = fs_1.default.readFileSync(this.valPath, 'utf8');
        // eslint-disable-next-line security/detect-non-literal-fs-filename
        const timeStr = fs_1.default.readFileSync(this.timePath, 'utf8');
        const valArr = JSON.parse(valStr);
        const timeArr = JSON.parse(timeStr);
        valArr.forEach((item) => this.val.set(item[0], item[1]));
        timeArr.forEach((item) => this.time.set(item[0], item[1]));
    }
    writeMaps() {
        const valStr = JSON.stringify([...this.val]);
        const timeStr = JSON.stringify([...this.time]);
        // eslint-disable-next-line security/detect-non-literal-fs-filename
        fs_1.default.writeFileSync(this.valPath, valStr);
        // eslint-disable-next-line security/detect-non-literal-fs-filename
        fs_1.default.writeFileSync(this.timePath, timeStr);
    }
    /**
     * Set a value in the cache
     * @param key Key to get value for
     * @param value Value to set
     * @param ttl Number of milliseconds for time to live
     */
    set(key, value, ttl) {
        this.val.set(key, value);
        this.time.set(key, new Date(Date.now() + ttl));
    }
    /**
     * Fetch a value from the cache
     * @param key Key to get value for
     * @returns Value if it exists and is not expired, undefined otherwise
     */
    get(key) {
        const now = new Date();
        const ttl = this.time.get(key);
        if (!ttl) {
            return undefined;
        }
        const ttlDate = new Date(ttl);
        if (ttlDate > now) {
            return this.val.get(key);
        }
        return undefined;
    }
}
exports.default = tcache;
//# sourceMappingURL=tcache.js.map